@@ -1,5 +1,5 @@
 from .coworks import TechMicroService, BizMicroService, Blueprint
 from .coworks import entry, hide
-from .mixins import FileParam
-from .proxy import MicroServiceProxy
-from .utils import jsonify
+from .globals import request
+
+__version__ = "0.6.0"
